# ixnetwork open traffic generator
![Upload Python Package](https://github.com/open-traffic-generator/ixnetwork/workflows/Upload%20Python%20Package/badge.svg)
[![pypi](https://img.shields.io/pypi/v/ixnetwork-open-traffic-generator.svg)](https://pypi.org/project/ixnetwork-open-traffic-generator)
[![python](https://img.shields.io/pypi/pyversions/ixnetwork-open-traffic-generator.svg)](https://pypi.python.org/pypi/ixnetwork-open-traffic-generator)
[![license](https://img.shields.io/badge/license-MIT-green.svg)](https://en.wikipedia.org/wiki/MIT_License)

The concrete IxNetwork implementation of the abstract-open-traffic-generator.


